struct penMath
(
	/******************************
		Name: Return local rotation from object
		Axis Orders:
			1 - XYZ
			2 - XZY
			3 - YZX
			4 - YXZ
			5 - ZXY
			6 - ZYX
			7 - XYX
			8 - YZY
			9 - ZXZ
	*******************************/
	fn localRot
		c:undefined	--Object to extract rotation from.
		p:c.parent	--Parent object or any other object to find the local rotation offset from.
		o:1 		--Axis order to calculate the Euler angles with.
		=
	(
		if c!=undefined then 
		(
			quatToEuler (c.transform * (inverse p.transform)).rotation order:o
		)else
		(
			eulerAngles 0 0 0
		)
	),
	
	/******************************
		Name: Hermite Function
		Set the input value from 0 to 1
		Adjust the t1 and t2 value to adjust exceleration curve.
		Defaults are set to create an ease out ease in curve. 
		t1 nd t2 values to get the same ease in and out curve. 
		*Use in conjuction with rangeClamp if your input value is not between 0 and 1.
	*******************************/
	fn hermite
		t1:3.0	--Tangent 1
		t2:2.0	--Tangent 2
		v:0.0	--Input value from 0 to 1
		=
	(
		h1 = -2*v^t1 + 3*v^t2 --Hermite Fn
	),
	
	/*****************************
		Name:Clamp Range
		Author: Paul Neale
		Client: PEN Productions Inc.
		Last Updated: May 30 2005
		Version: 0.02.0
		
		ToDo:
		
		Bugs:
		
		***Example Usage***
		Example:1 
		clampRange stVal:0.0 edVal:50.0 nStVal:0.0 nEdVal:100.0 val:25.0 clamp:false printVals:true
		Example:2 Invert a range
		clampRange stVal:-1.0 edVal:1.0 nStVal:1.0 nEdVal:-1.0 val:1.0 clamp:true printVals:true
	******************************/
	fn clampRange 
	stVal:0.0  			--Start value of in comming range.
	edVal:100.0 		--End value of incomming range.
	nStVal:0.0 			--Start value of out going range.
	nEdVal:1.0 			--End value of out going range.
	val:0.0 			--In value that will be converted.
	clamp:false			--If true will return a value that is clamped in the out going range. 
	=
	(
		local outVal
		
		--Get the percent of the inVal
		inRange=(edVal as float)-(stVal as float)
		inVal=(val as float)-(stVal as float)
		valPercent=inVal/inRange
		
		--Get the value of the based on the new range.
		nRange=(nEdVal as float)-(nStVal as float)
		
		--Invert the math if the nStVal> nEdVal so that values ranges can be inverted.
		if nStVal<=nEdVal then
		(
			outVal=(nRange*valPercent)-(abs nStVal)
		)else
		(
			outVal=(nRange*valPercent)+(abs nStVal)
		)
		
		--Clamp out going value to out range if clamp is true.
		if clamp then
		(
			if outVal<nStVal then (return nStVal)
			if outVal>nEdval then (return nEdVal)
		)
		return outVal
	)
)
penMath=penMath()


/*
penMath.hermite()
*/










